@@ -1,7 +1,6 @@
 require 'spec_helper'
 
 describe 'rally::db' do
-
   shared_examples 'rally::db' do
     context 'with default parameters' do
       it { is_expected.to contain_oslo__db('rally_config').with(
@@ -16,21 +15,19 @@ describe 'rally::db' do
         :pool_timeout   => '<SERVICE DEFAULT>',
       )}
 
-      it 'should create sqlite rally directory' do
-        is_expected.to contain_file('/var/lib/rally').with(
-          :ensure => 'directory',
-          :owner  => 'root',
-          :group  => 'root',
-          :mode   => '0755',
-          :path   => '/var/lib/rally',
-        )
-      end
+      it { is_expected.to contain_file('/var/lib/rally').with(
+        :ensure => 'directory',
+        :owner  => 'root',
+        :group  => 'root',
+        :mode   => '0755',
+        :path   => '/var/lib/rally',
+      )}
     end
 
-
     context 'with specific parameters' do
       let :params do
-        { :database_connection     => 'mysql://rally:rally@localhost/rally',
+        {
+          :database_connection     => 'mysql://rally:rally@localhost/rally',
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
           :database_max_retries    => '11',
@@ -53,52 +50,40 @@ describe 'rally::db' do
         :max_overflow   => '21',
         :pool_timeout   => '21',
       )}
-      it 'should not create sqlite rally directory' do
-        is_expected.to_not contain_file('create_sqlite_directory')
-      end
+
+      it { is_expected.to_not contain_file('create_sqlite_directory') }
     end
 
     context 'with postgresql backend' do
       let :params do
-        { :database_connection => 'postgresql://rally:rally@localhost/rally', }
-      end
-
-      it 'install the proper backend package' do
-        is_expected.to contain_package('python-psycopg2').with(:ensure => 'present')
+        {
+          :database_connection => 'postgresql://rally:rally@localhost/rally'
+        }
       end
 
+      it { is_expected.to contain_package('python-psycopg2').with_ensure('present') }
     end
 
     context 'with incorrect database_connection string' do
       let :params do
-        { :database_connection => 'foodb://rally:rally@localhost/rally', }
+        {
+          :database_connection => 'foodb://rally:rally@localhost/rally'
+        }
       end
 
-      it_raises 'a Puppet::Error', /validate_re/
+      it { should raise_error(Puppet::Error, /validate_re/) }
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-        :operatingsystem => 'Debian',
-        :operatingsystemrelease => 'jessie',
-      })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      it_behaves_like 'rally::db'
     end
-
-    it_configures 'rally::db'
   end
-
-  context 'on Redhat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'RedHat',
-        :operatingsystemrelease => '7.1',
-      })
-    end
-
-    it_configures 'rally::db'
-  end
-
 end
